@@ -598,7 +598,7 @@ bool Util::deleteAttachment(KMime::Content *node)
     bodyMessage += ("\nname=\"") + name.toUtf8() + "\"";
     bodyMessage += ("\nfilename=\"") + filename.toUtf8() + "\"";
     deletePart->setBody(bodyMessage);
-    delete parentNode->takeContent(node);
+    parentNode->takeContent(node);
     parentNode->appendContent(deletePart);
 
     parentNode->assemble();
