@@ -7,7 +7,7 @@
 */
 
 #pragma once
-
+#include "config-messageviewer.h"
 #include "csshelper.h"
 #include "messageviewer/viewerplugininterface.h"
 #include "messageviewer_private_export.h"
@@ -60,7 +60,7 @@ namespace TextAddonsWidgets
 {
 class SlideContainer;
 }
-#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
 namespace TextEditTextToSpeech
 {
 class TextToSpeechContainerWidget;
@@ -452,7 +452,7 @@ public:
     void setFolderIdentity(uint folderIdentity);
 
     [[nodiscard]] RemoteContentMenu *remoteContentMenu() const;
-    void showMdnInformations(const QPair<QString, bool> &mdnInfo);
+    void showMdnInformations(const QString &message, bool canDeny);
     void mdnWarningAnimatedHide();
 
 private Q_SLOTS:
@@ -591,7 +591,7 @@ Q_SIGNALS:
     void itemRemoved();
     void makeResourceOnline(MessageViewer::Viewer::ResourceOnlineMode mode);
 
-    void changeDisplayMail(Viewer::DisplayFormatMessage, bool);
+    void changeDisplayMail(MessageViewer::Viewer::DisplayFormatMessage, bool);
     void moveMessageToTrash();
     void pageIsScrolledToBottom(bool);
     void printingFinished();
@@ -714,7 +714,7 @@ public:
     MessageViewer::OpenSavedFileFolderWidget *mOpenSavedFileFolderWidget = nullptr;
     WebEngineViewer::SubmittedFormWarningWidget *mSubmittedFormWarning = nullptr;
     WebEngineViewer::TrackingWarningWidget *mMailTrackingWarning = nullptr;
-#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
     TextEditTextToSpeech::TextToSpeechContainerWidget *mTextToSpeechContainerWidget = nullptr;
 #endif
     Viewer::DisplayFormatMessage mDisplayFormatMessageOverwrite;
